Cleans a character vector by converting to lowercase, removing or replacing specific punctuation, normalizing commas, and squishing excess whitespace.
Examples
clean_text(c("Hello World!?", "This--is\tR.\nTesting: 1, 2, , 3;"))
#> [1] "hello world" "this is r testing 1, 2, , 3"